@@ -1,6 +1,6 @@
 import builtins
 from contextlib import contextmanager
-from typing import Any, Generator
+from typing import Any, Callable, Generator, Optional
 from unicodeit import replace
 from rich import pretty, traceback
 from rich import print as rprint
@@ -8,6 +8,7 @@ from rich import print as rprint
 
 PRINT = builtins.print
 
+
 def console_latex(
     latex: str,
 ) -> str:
@@ -16,10 +17,14 @@ def console_latex(
 
 @contextmanager
 def replace_print(
-    print_method,
+    print_method: Optional[Callable] = None,
 ) -> Generator[None, Any, None]:
+    # base_print = (
+    #     __builtins__["print"] if isinstance(__builtins__, dict) else __builtins__.print
+    # )
+    base_print = print
     original = builtins.print
-    builtins.print = print_method
+    builtins.print = print_method if print_method is not None else base_print
     try:
         yield
     finally:
